jenkins-bot has submitted this change and it was merged.

Change subject: Make jquery.suggestions obey maxRows setting
......................................................................


Make jquery.suggestions obey maxRows setting

The maxRows setting was previously unused and had no effect. This patch
passes the property in the fetch() call, and makes it enforce the setting.

Also updates mediawiki.userSuggest.js to use response()

The previously unused setting of 7 is changed to 10 to match current
behaviour.

Bug: T39316
Change-Id: I2873963aba9fd751607d11904b94bfcec8eb2d32
---
M resources/src/jquery/jquery.suggestions.js
M resources/src/mediawiki/mediawiki.searchSuggest.js
M resources/src/mediawiki/mediawiki.userSuggest.js
3 files changed, 12 insertions(+), 10 deletions(-)

Approvals:
  Bartosz Dziewoński: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/resources/src/mediawiki/mediawiki.searchSuggest.js 
b/resources/src/mediawiki/mediawiki.searchSuggest.js
index d372e8f..7b7ccf3 100644
--- a/resources/src/mediawiki/mediawiki.searchSuggest.js
+++ b/resources/src/mediawiki/mediawiki.searchSuggest.js
@@ -119,7 +119,7 @@
                ];
                $( searchboxesSelectors.join( ', ' ) )
                        .suggestions( {
-                               fetch: function ( query, response ) {
+                               fetch: function ( query, response, maxRows ) {
                                        var node = this[0];
 
                                        api = api || new mw.Api();
@@ -128,6 +128,7 @@
                                                action: 'opensearch',
                                                search: query,
                                                namespace: 0,
+                                               limit: maxRows,
                                                suggest: ''
                                        } ).done( function ( data ) {
                                                response( data[ 1 ] );
diff --git a/resources/src/mediawiki/mediawiki.userSuggest.js 
b/resources/src/mediawiki/mediawiki.userSuggest.js
index aed093c..3964f0b 100644
--- a/resources/src/mediawiki/mediawiki.userSuggest.js
+++ b/resources/src/mediawiki/mediawiki.userSuggest.js
@@ -5,9 +5,8 @@
        var api, config;
 
        config = {
-               fetch: function ( userInput ) {
-                       var $textbox = this,
-                               node = this[0];
+               fetch: function ( userInput, response, maxRows ) {
+                       var node = this[0];
 
                        api = api || new mw.Api();
 
@@ -16,13 +15,13 @@
                                list: 'allusers',
                                // Prefix of list=allusers is case sensitive. 
Normalise first
                                // character to uppercase so that "fo" may 
yield "Foo".
-                               auprefix: userInput.charAt( 0 ).toUpperCase() + 
userInput.slice( 1 )
+                               auprefix: userInput.charAt( 0 ).toUpperCase() + 
userInput.slice( 1 ),
+                               aulimit: maxRows
                        } ).done( function ( data ) {
                                var users = $.map( data.query.allusers, 
function ( userObj ) {
                                        return userObj.name;
                                } );
-                               // Set the results as the autocomplete options
-                               $textbox.suggestions( 'suggestions', users );
+                               response( users );
                        } ) );
                },
                cancel: function () {

diff --git a/resources/src/jquery/jquery.suggestions.js 
b/resources/src/jquery/jquery.suggestions.js
index a83a70a..f1b214e 100644
--- a/resources/src/jquery/jquery.suggestions.js
+++ b/resources/src/jquery/jquery.suggestions.js
@@ -28,7 +28,7 @@
  * suggestions: Suggestions to display
  *             Type: Array of strings
  * maxRows: Maximum number of suggestions to display at one time
  *             Type: Number, Range: 1 - 100, Default: 7
  * delay: Number of ms to wait for the user to stop typing
  *             Type: Number, Range: 0 - 1200, Default: 120
  * cache: Whether to cache results from a fetch
@@ -125,6 +125,7 @@
                                                context.data.$textbox,
                                                val,
                                                function ( suggestions ) {
+                                                       suggestions = 
suggestions.slice( 0, context.config.maxRows );
                                                        
context.data.$textbox.suggestions( 'suggestions', suggestions );
                                                        if ( 
context.config.cache ) {
                                                                cache[ val ] = {
@@ -132,7 +133,8 @@
                                                                        
timestamp: +new Date()
                                                                };
                                                        }
-                                               }
+                                               },
+                                               context.config.maxRows
                                        );
                                }
                        }
@@ -513,7 +515,7 @@
                                        result: {},
                                        $region: $( this ),
                                        suggestions: [],
-                                       maxRows: 7,
+                                       maxRows: 10,
                                        delay: 120,
                                        cache: false,
                                        cacheMaxAge: 60000,
@@ -28,7 +28,7 @@
  *             Type: Array of strings
  * maxRows: Maximum number of suggestions to display at one time
- *             Type: Number, Range: 1 - 100, Default: 7
+ *             Type: Number, Range: 1 - 100, Default: 10
  * delay: Number of ms to wait for the user to stop typing
  *             Type: Number, Range: 0 - 1200, Default: 120
-- 
To view, visit https://gerrit.wikimedia.org/r/182642
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I2873963aba9fd751607d11904b94bfcec8eb2d32
Gerrit-PatchSet: 4
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Unicodesnowman <[email protected]>
Gerrit-Reviewer: Bartosz Dziewoński <[email protected]>
Gerrit-Reviewer: Jack Phoenix <[email protected]>
Gerrit-Reviewer: Krinkle <[email protected]>
Gerrit-Reviewer: Unicodesnowman <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to